==> spring-security-core-5.6.8-sources.jar: org/springframework/security/authentication/InsufficientAuthenticationException.java <==
/*
 * Copyright 2004, 2005, 2006 Acegi Technology Pty Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.security.authentication;

import org.springframework.security.core.AuthenticationException;

/**
 * Thrown if an authentication request is rejected because the credentials are not
 * sufficiently trusted.
 * <p>
 * {@link org.springframework.security.access.AccessDecisionVoter}s will typically throw
 * this exception if they are dissatisfied with the level of the authentication, such as
 * if performed using a remember-me mechanism or anonymously. The
 * {@code ExceptionTranslationFilter} will then typically cause the
 * {@code AuthenticationEntryPoint} to be called, allowing the principal to authenticate
 * with a stronger level of authentication.
 *
 * @author Ben Alex
 */
public class InsufficientAuthenticationException extends AuthenticationException {

	/**
	 * Constructs an <code>InsufficientAuthenticationException</code> with the specified
	 * message.
	 * @param msg the detail message
	 */
	public InsufficientAuthenticationException(String msg) {
		super(msg);
	}

	/**
	 * Constructs an <code>InsufficientAuthenticationException</code> with the specified
	 * message and root cause.
	 * @param msg the detail message
	 * @param cause root cause
	 */
	public InsufficientAuthenticationException(String msg, Throwable cause) {
		super(msg, cause);
	}

}

==> spring-security-core-6.5.2-sources.jar: org/springframework/security/authentication/InsufficientAuthenticationException.java <==
/*
 * Copyright 2004, 2005, 2006 Acegi Technology Pty Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.security.authentication;

import java.io.Serial;

import org.springframework.security.core.AuthenticationException;

/**
 * Thrown if an authentication request is rejected because the credentials are not
 * sufficiently trusted.
 * <p>
 * {@link org.springframework.security.authorization.AuthorizationManager}s will typically
 * throw this exception if they are dissatisfied with the level of the authentication,
 * such as if performed using a remember-me mechanism or anonymously. The
 * {@code ExceptionTranslationFilter} will then typically cause the
 * {@code AuthenticationEntryPoint} to be called, allowing the principal to authenticate
 * with a stronger level of authentication.
 *
 * @author Ben Alex
 */
public class InsufficientAuthenticationException extends AuthenticationException {

	@Serial
	private static final long serialVersionUID = -5514084346181236128L;

	/**
	 * Constructs an <code>InsufficientAuthenticationException</code> with the specified
	 * message.
	 * @param msg the detail message
	 */
	public InsufficientAuthenticationException(String msg) {
		super(msg);
	}

	/**
	 * Constructs an <code>InsufficientAuthenticationException</code> with the specified
	 * message and root cause.
	 * @param msg the detail message
	 * @param cause root cause
	 */
	public InsufficientAuthenticationException(String msg, Throwable cause) {
		super(msg, cause);
	}

}
